packPOOII
==============

#### Pacote utilizado para fazer alterações em arquivos de texto. 

## Instalação:

```
pip install packPOOII
```

## Como usar:

```
from packPOOII import packPOOII
s = packPOOII.PackPOOII()
s.subString(palavra)

```
## Funções: 

```
subString(): Procura uma sub-string dentro de uma determinada string
deleteLine(): Deleta uma linha de um arquivo de texto
popularidade(): Retorna quantas vezes uma ou mais palavras aparecem em um arquivo de texto
cor(): Retorna a palavra com uma cor escolhida
```